@@ -32,6 +32,10 @@ xx(dumpconfig,
    "Dump active configuration",
    "dumpconfig <filename>\n")
 
+xx(formats,
+   "List available metadata formats",
+   "formats\n")
+
 xx(help,
    "Display help for commands",
    "help <command>" "\n")
@@ -428,6 +432,7 @@ xx(pvmove,
    "pvmove " "\n"
    "\t[--abort]\n"
    "\t[-A|--autobackup {y|n}]\n"
+   "\t[--alloc AllocationType]\n"
    "\t[-b|--background]\n"
    "\t[-d|--debug]\n "
    "\t[-f|--force]\n"
@@ -438,12 +443,11 @@ xx(pvmove,
    "\t[--version]\n"
    "\t[{-n|--name} LogicalVolume]\n"
 /* "\t[{-n|--name} LogicalVolume[:LogicalExtent[-LogicalExtent]...]]\n" */
-   "\tSourcePhysicalVolume\n"
-/* "\tSourcePhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]}\n" */
+   "\tSourcePhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]}\n"
    "\t[DestinationPhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]...]\n",
 
-   abort_ARG, autobackup_ARG, background_ARG, force_ARG, interval_ARG, name_ARG,
-   test_ARG)
+   abort_ARG, alloc_ARG, autobackup_ARG, background_ARG, force_ARG,
+   interval_ARG, name_ARG, test_ARG)
 
 xx(pvremove,
    "Remove LVM label(s) from physical volume(s)",
@@ -451,7 +455,6 @@ xx(pvremove,
    "\t[-d|--debug]" "\n"
    "\t[-f[f]|--force [--force]] " "\n"
    "\t[-h|-?|--help] " "\n"
-   "\t[-y|--yes]" "\n"
    "\t[-t|--test] " "\n"
    "\t[-v|--verbose] " "\n"
    "\t[-y|--yes]" "\n"
@@ -514,6 +517,10 @@ xx(pvscan,
    exported_ARG, ignorelockingfailure_ARG, novolumegroup_ARG, partial_ARG,
    short_ARG, uuid_ARG)
 
+xx(segtypes,
+   "List available segment types",
+   "segtypes\n")
+
 xx(vgcfgbackup,
    "Backup volume group configuration(s)",
    "vgcfgbackup " "\n"
